==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/installer/messages/ru/base.php <==
<?php
return array (
  '<strong>Admin</strong> Account' => '<strong>Учётная запись</strong> администратора',
  '<strong>Configuration</strong>' => '<strong>Конфигурация</strong>',
  '<strong>Congratulations</strong>. You\'re done.' => '<strong>Поздравляем.</strong> Установка закончена.',
  '<strong>Database</strong> Configuration' => '<strong>Настройки</strong> базы данных',
  '<strong>Example</strong> contents' => '<strong>Демо</strong> данные',
  '<strong>Pretty URLs</strong> configuration' => 'Конфигурация <strong>Красивые URL</strong>',
  '<strong>Scheduled jobs</strong>' => '<strong>Запланированные задания</strong>',
  '<strong>System</strong> Check' => '<strong>Проверка</strong> системы',
  '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Добро пожаловать</strong> в HumHub<br>Это Ваша социальная сеть',
  'Add following the lines to the crontab:' => 'Добавьте в crontab следующие строки:',
  'Allow access for non-registered users to public content (guest access)' => 'Разрешить доступ для незарегистрированных пользователей к содержанию сайта (гостевой доступ)',
  'Allow friendships between members' => 'Разрешить дружбу между пользователями',
  'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'Ниже Вы должны ввести свои данные для подключения к базе данных. Если Вы не уверены в них или затрудняетесь корректности, пожалуйста, обратитесь к системному администратору.',
  'Calvin Klein – Between love and madness lies obsession.' => 'Между любовью и безумием лежит одержимость. - Calvin Klein',
  'Check again' => 'Проверьте ещё раз',
  'Congratulations! Everything is ok and ready to start over!' => 'Поздравляем! Всё в порядке и готово к установке!',
  'Create Admin Account' => 'Создать учётную запись администратора',
  'Create the database if it doesn\'t exist yet.' => 'Создайте базу данных, если она еще не существует.',
  'Downloading & Installing Modules...' => 'Загрузка и установка модулей ...',
  'External users can register (show registration form on login)' => 'Каждый может зарегистрироваться (Регистрация будет доступна при входе)',
  'Here you can decide how new, unregistered users can access HumHub.' => 'Здесь Вы можете решить, как новые и незарегистрированные пользователи могут получить доступ к HumHub.',
  'Hostname' => 'Имя хоста',
  'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'Имя или адрес хоста для сервера базы данных MySQL (например, localhost, если MySQL работает на той же машине что и устанавливаемый HumHub)',
  'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub является очень гибким и может быть скорректирован и/или расширен различными приложениями, благодаря своим модулям. Следующие модули являются лишь частью общего количества модулей, но они как мы думаем, являются наиболее важными на старте работы HubHum.<br><br>Вы всегда можете установить или удалить модули позже. Вы можете найти больше доступных модулей после установки в Панели Управления.',
  'HumHub uses cron jobs to execute scheduled or to run potentially heavy tasks such as sending out email summaries and notifications or optimizing the search index.' => 'HumHub использует задания cron для выполнения запланированных или потенциально тяжелых задач, таких как отправка сводок и уведомлений по электронной почте или оптимизация поискового индекса.',
  'I want to use HumHub for:' => 'Я хочу использовать HumHub для:',
  'In order to activate this feature, it is necessary to edit the HumHub configuration and, potentially, the configuration of the WebServer.' => 'Чтобы активировать эту функцию, необходимо отредактировать конфигурацию HumHub и, возможно, конфигурацию веб-сервера.',
  'Initializing database...' => 'Инициализация базы данных ...',
  'Installation Example:' => 'Пример установки:',
  'My club' => 'Мой клуб',
  'My community' => 'Моё комьюнити',
  'My company (Social Intranet / Project management)' => 'Моя компания (Социальный Интранет / Управление проектами)',
  'My educational institution (school, university)' => 'Моё образовательное учреждение (школа, университет)',
  'Name of Database' => 'Имя базы данных',
  'Name of your network' => 'Название Вашей социальной сети',
  'Newly registered users have to be activated by an admin first' => 'Новые пользователи должны быть сначала проверены администратором',
  'Next' => 'Далее',
  'Nike – Just buy it. :wink:' => 'Nike – Просто купите это. :wink:',
  'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Конечно, Ваша новая социальная сеть нуждается в названии. Пожалуйста, измените название по умолчанию на то, которое Вам нравится. (Например, название Вашей компании, организации или клуба)',
  'Ohh, something went wrong!' => 'Ой, что-то пошло не так!',
  'On HumHub\'s side, you will need to edit the configuration file <code>{configFile}</code> and add the following block:' => 'На стороне HumHub вам нужно будет отредактировать файл конфигурации <code>{configFile}</code> и добавить следующий блок:',
  'Open the crontab of HumHub/PHP process user e.g. <code>{user}</code>.' => 'Откройте crontab пользователя процесса HumHub/PHP, например, <code>{user}</code>.',
  'Optional: Port of your MySQL Database Server. Leave empty to use default port.' => 'Необязательно: порт вашего сервера базы данных MySQL. Оставьте пустым, чтобы использовать порт по умолчанию.',
  'Our documentation provides a more detailed look into <a href="{link}" target="_blank">Pretty URLs</a>.' => 'В нашей документации представлено более подробное описание <a href="{link}">красивых URL</a>.',
  'Password' => 'Пароль',
  'Per default, the HumHub URL includes an <code>index.php</code> file in the address, resulting in a URL that looks like "<a>https://example.com/index.php?r=dashboard%2Fdashboard</a>" for example. By using the Pretty URL or URL Rewriting feature, it is possible to create shorter and easier to understand URLs, such as "<a>https://example.com/dashboard</a>".' => 'По умолчанию URL-адрес HumHub включает в себя файл <code>index.php</code>, в результате чего URL-адрес выглядит так: "<a>https://example.com/index.php?r=dashboard%2Fdashboard</a>" , например. Используя функцию «Красивый URL-адрес» или «Перезапись URL-адресов», можно создавать более короткие и понятные URL-адреса, например «<a>https://example.com/dashboard</a>».',
  'Port' => 'Порт',
  'Recommended <strong>Modules</strong>' => '<strong>Рекомендованные</strong> Модули',
  'Registered members can invite new users via email' => 'Зарегистрированные участники могут приглашать новых пользователей по email',
  'Registered members can invite new users via link' => 'Зарегистрированные участники могут приглашать новых пользователей по ссылке.',
  'Security <strong>Settings</strong>' => '<strong>Настройки</strong> Безопасности',
  'Set up example content (recommended)' => 'Использовать демо контент (рекомендуется)',
  'Sign in' => 'Перейти к сайту',
  'Skip this step, I want to set up everything manually' => 'Пропустить этот шаг, для того, чтобы настроить всё вручную',
  'Social Network <strong>Name</strong>' => '<strong>Выберите</strong> название',
  'The installation completed successfully! Have fun with your new social network.' => 'Установка прошла успешно! Удачи в ваших начинаниях.',
  'The name of the database you want to run HumHub in.' => 'Имя базы данных MySQL',
  'This overview shows all system requirements of HumHub.' => 'Список ниже содежит все системные требования и рекомендации для HumHub.',
  'This topic is covered in more detail in our <a href="{link}" target="_blank">documentation</a>. If you have trouble setting up the job scheduling described in the documentation, please contact your server administrator for support.' => 'Эта тема более подробно рассмотрена в нашей <a href="{link}">documentation</a>&gt;. Если у вас возникли проблемы с настройкой планирования заданий, описанного в документации, обратитесь за поддержкой к администратору сервера.',
  'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Мастер установки настроит Ваш собственный экземпляр HumHub.<br><br>Чтобы продолжить, нажмите кнопку Далее.',
  'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'Чтобы избежать пустой главной страницы после завершения установки, HumHub может установить некоторые демо данные для Вас. Это даст Вам хороший первоначальный общий вид и понимание того, как HumHub работает. Вы всегда можете удалить демо содержимое в любой момент.',
  'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'Для упрощения процесса установки, у нас есть предопределенные настройки для наиболее распространенных случаев использования HumHub с различными опциями для модулей и настроек. Вы можете настроить их на следующем этапе.',
  'Username' => 'Имя пользователя',
  'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Мы ищем слоганы для известных брендов. Может быть, Вы можете придумать свои примеры?',
  'Welcome Space' => 'Добро пожаловать в сообщество',
  'Yay! I\'ve just installed HumHub :sunglasses:' => 'Ура! Я только что установил HumHub :sunglasses:',
  'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Вы почти закончили. На этом этапе Вы должны заполнить форму, чтобы создать учётную запись администратора. С этого аккаунта Вы будете управлять всем сайтом.',
  'Your MySQL password.' => 'Пароль MySQL',
  'Your MySQL username' => 'Имя пользователя MySQL',
  'Your first sample space to discover the platform.' => 'Ваша первое пробное сообщество на данной платформе.',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/installer/messages/ru/base.php <==
<?php
return array (
  '<strong>Admin</strong> Account' => '<strong>Учётная запись</strong> администратора',
  '<strong>Configuration</strong>' => '<strong>Конфигурация</strong>',
  '<strong>Congratulations</strong>. You\'re done.' => '<strong>Поздравляем.</strong> Установка закончена.',
  '<strong>Database</strong> Configuration' => '<strong>Настройки</strong> базы данных',
  '<strong>Example</strong> contents' => '<strong>Демо</strong> данные',
  '<strong>Pretty URLs</strong> configuration' => 'Конфигурация <strong>Красивые URL</strong>',
  '<strong>Scheduled jobs</strong>' => '<strong>Запланированные задания</strong>',
  '<strong>System</strong> Check' => '<strong>Проверка</strong> системы',
  '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Добро пожаловать</strong> в HumHub<br>Это Ваша социальная сеть',
  'Add following the lines to the crontab:' => 'Добавьте в crontab следующие строки:',
  'Allow access for non-registered users to public content (guest access)' => 'Разрешить доступ для незарегистрированных пользователей к содержанию сайта (гостевой доступ)',
  'Allow friendships between members' => 'Разрешить дружбу между пользователями',
  'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'Ниже Вы должны ввести свои данные для подключения к базе данных. Если Вы не уверены в них или затрудняетесь корректности, пожалуйста, обратитесь к системному администратору.',
  'Calvin Klein – Between love and madness lies obsession.' => 'Между любовью и безумием лежит одержимость. - Calvin Klein',
  'Check again' => 'Проверьте ещё раз',
  'Congratulations! Everything is ok and ready to start over!' => 'Поздравляем! Всё в порядке и готово к установке!',
  'Create Admin Account' => 'Создать учётную запись администратора',
  'Create the database if it doesn\'t exist yet.' => 'Создайте базу данных, если она еще не существует.',
  'Downloading & Installing Modules...' => 'Загрузка и установка модулей ...',
  'External users can register (show registration form on login)' => 'Каждый может зарегистрироваться (Регистрация будет доступна при входе)',
  'Here you can decide how new, unregistered users can access HumHub.' => 'Здесь Вы можете решить, как новые и незарегистрированные пользователи могут получить доступ к HumHub.',
  'Hostname' => 'Имя хоста',
  'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'Имя или адрес хоста для сервера базы данных MySQL (например, localhost, если MySQL работает на той же машине что и устанавливаемый HumHub)',
  'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub является очень гибким и может быть скорректирован и/или расширен различными приложениями, благодаря своим модулям. Следующие модули являются лишь частью общего количества модулей, но они как мы думаем, являются наиболее важными на старте работы HubHum.<br><br>Вы всегда можете установить или удалить модули позже. Вы можете найти больше доступных модулей после установки в Панели Управления.',
  'HumHub uses cron jobs to execute scheduled or to run potentially heavy tasks such as sending out email summaries and notifications or optimizing the search index.' => 'HumHub использует задания cron для выполнения запланированных или потенциально тяжелых задач, таких как отправка сводок и уведомлений по электронной почте или оптимизация поискового индекса.',
  'I want to use HumHub for:' => 'Я хочу использовать HumHub для:',
  'In order to activate this feature, it is necessary to edit the HumHub configuration and, potentially, the configuration of the WebServer.' => 'Чтобы активировать эту функцию, необходимо отредактировать конфигурацию HumHub и, возможно, конфигурацию веб-сервера.',
  'Initializing database...' => 'Инициализация базы данных ...',
  'Installation Example:' => 'Пример установки:',
  'My club' => 'Мой клуб',
  'My community' => 'Моё комьюнити',
  'My company (Social Intranet / Project management)' => 'Моя компания (Социальный Интранет / Управление проектами)',
  'My educational institution (school, university)' => 'Моё образовательное учреждение (школа, университет)',
  'Name of Database' => 'Имя базы данных',
  'Name of your network' => 'Название Вашей социальной сети',
  'Newly registered users have to be activated by an admin first' => 'Новые пользователи должны быть сначала проверены администратором',
  'Next' => 'Далее',
  'Nike – Just buy it. :wink:' => 'Nike – Просто купите это. :wink:',
  'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Конечно, Ваша новая социальная сеть нуждается в названии. Пожалуйста, измените название по умолчанию на то, которое Вам нравится. (Например, название Вашей компании, организации или клуба)',
  'Ohh, something went wrong!' => 'Ой, что-то пошло не так!',
  'On HumHub\'s side, you will need to edit the configuration file <code>{configFile}</code> and add the following block:' => 'На стороне HumHub вам нужно будет отредактировать файл конфигурации <code>{configFile}</code> и добавить следующий блок:',
  'Open the crontab of HumHub/PHP process user e.g. <code>{user}</code>.' => 'Откройте crontab пользователя процесса HumHub/PHP, например, <code>{user}</code>.',
  'Optional: Port of your MySQL Database Server. Leave empty to use default port.' => 'Необязательно: порт вашего сервера базы данных MySQL. Оставьте пустым, чтобы использовать порт по умолчанию.',
  'Our documentation provides a more detailed look into <a href="{link}" target="_blank">Pretty URLs</a>.' => 'В нашей документации представлено более подробное описание <a href="{link}">красивых URL</a>.',
  'Password' => 'Пароль',
  'Per default, the HumHub URL includes an <code>index.php</code> file in the address, resulting in a URL that looks like "<a>https://example.com/index.php?r=dashboard%2Fdashboard</a>" for example. By using the Pretty URL or URL Rewriting feature, it is possible to create shorter and easier to understand URLs, such as "<a>https://example.com/dashboard</a>".' => 'По умолчанию URL-адрес HumHub включает в себя файл <code>index.php</code>, в результате чего URL-адрес выглядит так: "<a>https://example.com/index.php?r=dashboard%2Fdashboard</a>" , например. Используя функцию «Красивый URL-адрес» или «Перезапись URL-адресов», можно создавать более короткие и понятные URL-адреса, например «<a>https://example.com/dashboard</a>».',
  'Port' => 'Порт',
  'Recommended <strong>Modules</strong>' => '<strong>Рекомендованные</strong> Модули',
  'Registered members can invite new users via email' => 'Зарегистрированные участники могут приглашать новых пользователей по email',
  'Registered members can invite new users via link' => 'Зарегистрированные участники могут приглашать новых пользователей по ссылке.',
  'Security <strong>Settings</strong>' => '<strong>Настройки</strong> Безопасности',
  'Set up example content (recommended)' => 'Использовать демо контент (рекомендуется)',
  'Sign in' => 'Перейти к сайту',
  'Skip this step, I want to set up everything manually' => 'Пропустить этот шаг, для того, чтобы настроить всё вручную',
  'Social Network <strong>Name</strong>' => '<strong>Выберите</strong> название',
  'The installation completed successfully! Have fun with your new social network.' => 'Установка прошла успешно! Удачи в ваших начинаниях.',
  'The name of the database you want to run HumHub in.' => 'Имя базы данных MySQL',
  'This overview shows all system requirements of HumHub.' => 'Список ниже содежит все системные требования и рекомендации для HumHub.',
  'This topic is covered in more detail in our <a href="{link}" target="_blank">documentation</a>. If you have trouble setting up the job scheduling described in the documentation, please contact your server administrator for support.' => 'Эта тема более подробно рассмотрена в нашей <a href="{link}">documentation</a>&gt;. Если у вас возникли проблемы с настройкой планирования заданий, описанного в документации, обратитесь за поддержкой к администратору сервера.',
  'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Мастер установки настроит Ваш собственный экземпляр HumHub.<br><br>Чтобы продолжить, нажмите кнопку Далее.',
  'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'Чтобы избежать пустой главной страницы после завершения установки, HumHub может установить некоторые демо данные для Вас. Это даст Вам хороший первоначальный общий вид и понимание того, как HumHub работает. Вы всегда можете удалить демо содержимое в любой момент.',
  'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'Для упрощения процесса установки, у нас есть предопределенные настройки для наиболее распространенных случаев использования HumHub с различными опциями для модулей и настроек. Вы можете настроить их на следующем этапе.',
  'Username' => 'Логин',
  'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Мы ищем слоганы для известных брендов. Может быть, Вы можете придумать свои примеры?',
  'Welcome Space' => 'Добро пожаловать в сообщество',
  'Yay! I\'ve just installed HumHub :sunglasses:' => 'Ура! Я только что установил HumHub :sunglasses:',
  'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Вы почти закончили. На этом этапе Вы должны заполнить форму, чтобы создать учётную запись администратора. С этого аккаунта Вы будете управлять всем сайтом.',
  'Your MySQL password.' => 'Пароль MySQL',
  'Your MySQL username' => 'Имя пользователя MySQL',
  'Your first sample space to discover the platform.' => 'Ваше первое демонстрационное сообщество для знакомства с платформой.',
);
